pub struct Property {
pub class: Option<String>,
pub group: Option<String>,
pub name: String,
pub ns: Option<String>,
pub remarks: Option<String>,
pub uuid: Option<String>,
pub value: String,
}Expand description
An attribute, characteristic, or quality of the containing object expressed as a namespace qualified name/value pair.
Fields
class: Option<String>A textual label that provides a sub-type or characterization of the property’s name.
group: Option<String>An identifier for relating distinct sets of properties.
name: StringA textual label, within a namespace, that uniquely identifies a specific attribute, characteristic, or quality of the property’s containing object.
ns: Option<String>A namespace qualifying the property’s name. This allows different organizations to associate distinct semantics with the same name.
remarks: Option<String>uuid: Option<String>A unique identifier for a property.
value: StringIndicates the value of the attribute, characteristic, or quality.