CombinationMethod

Enum CombinationMethod 

#[non_exhaustive]
pub enum CombinationMethod { Keep, Merge, UseFirst, }
Declare how clashing controls should be handled.

A label that indicates the nature of a resource, as a data serialization or format.

A non-empty string with leading and trailing whitespace disallowed. Whitespace is: U+9, U+10, U+32 or [ ]+

In case where the href points to a back-matter/resource, this value will indicate the URI fragment to append to any rlink associated with the resource. This value MUST be URI encoded.

Indicates the value of the attribute, characteristic, or quality.

A glob expression matching the IDs of one or more controls to be selected.

A formal (executable) expression of a constraint.

A parameter value or set of values.

A single line of an address.

City, town or geographical region for the mailing address.

The ISO 3166-1 alpha-2 country code for the mailing address.

Postal or ZIP code for mailing address.

State, province or analogous geographical region for a mailing address.

The OSCAL model version the document was authored against and will conform to as valid.

The full name of the party. This is typically the legal name associated with the party.

A short common name, abbreviation, or acronym for the party.

Used to distinguish a specific revision of an OSCAL document from other previous and future versions.

A short common name, abbreviation, or acronym for the role.

The digest method by which a hash is derived.

Indicates the type of phone number.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Keep



Merge



UseFirst