pub struct Addition {
pub by_id: Option<String>,
pub links: Option<Vec<Link>>,
pub params: Option<Vec<Parameter>>,
pub parts: Option<Vec<Part>>,
pub position: Option<Position>,
pub props: Option<Vec<Property>>,
pub title: Option<String>,
}Expand description
Specifies contents to be added into controls, in resolution.
Fields
by_id: Option<String>Target location of the addition.
links: Option<Vec<Link>>params: Option<Vec<Parameter>>parts: Option<Vec<Part>>position: Option<Position>Where to add the new content with respect to the targeted element (beside it or inside it).
props: Option<Vec<Property>>title: Option<String>A name given to the control, which may be used by a tool for display and navigation.