pub struct MatchControlsByPattern {
pub pattern: Option<String>,
}Expand description
Selecting a set of controls by matching their IDs with a wildcard pattern.
Fields
pattern: Option<String>A glob expression matching the IDs of one or more controls to be selected.