InventoryItemBuilder

Struct InventoryItemBuilder 

pub struct InventoryItemBuilder { /* private fields */ }
Builder for InventoryItem.

Implementations

Source

impl InventoryItemBuilder

pub fn description<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self

A summary of the inventory item stating its purpose within the system.

pub fn implemented_components<VALUE: Into<Vec<ImplementedComponent>>>( &mut self, value: VALUE, ) -> &mut Self

pub fn props<VALUE: Into<Vec<Property>>>(&mut self, value: VALUE) -> &mut Self

pub fn remarks<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self

pub fn responsible_parties<VALUE: Into<Vec<ResponsibleParty>>>( &mut self, value: VALUE, ) -> &mut Self

pub fn uuid<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self

A machine-oriented, globally unique identifier with cross-instance scope that can be used to reference this inventory item elsewhere in this or other OSCAL instances. The locally defined UUID of the inventory item can be used to reference the data item locally or globally (e.g., in an imported OSCAL instance). This UUID should be assigned per-subject, which means it should be consistently used to identify the same subject across revisions of the document.

pub fn build(&self) -> Result<InventoryItem, InventoryItemBuilderError>

Builds a new InventoryItem.

Errors

If a required field has not been initialized.