ProvidedControlImplementation

Struct ProvidedControlImplementation 

pub struct ProvidedControlImplementation {
    pub description: String,
    pub links: Option<Vec<Link>>,
    pub props: Option<Vec<Property>>,
    pub remarks: Option<String>,
    pub responsible_roles: Option<Vec<ResponsibleRole>>,
    pub uuid: String,
}
Describes a capability which may be inherited by a leveraging system.

Fields

description: String

An implementation statement that describes the aspects of the control or control statement implementation that can be provided to another system leveraging this system.

links: Option<Vec<Link>>props: Option<Vec<Property>>remarks: Option<String>responsible_roles: Option<Vec<ResponsibleRole>>uuid: String

A machine-oriented, globally unique identifier with cross-instance scope that can be used to reference this provided entry elsewhere in this or other OSCAL instances. The locally defined UUID of the provided entry can be used to reference the data item locally or globally (e.g., in an imported OSCAL instance). This UUID should be assigned per-subject, which means it should be consistently used to identify the same subject across revisions of the document.