#[non_exhaustive]pub enum ItemNameReference {
Link,
Map,
Mapping,
Param,
Part,
Prop,
}Expand description
Identify items to remove by the name of the item’s information object name, e.g. title or prop.
Name of the file before it was encoded as Base64 to be embedded in a resource. This is the name that will be assigned to the file when the file is decoded.
A non-colonized name as defined by XML Schema Part 2: Datatypes Second Edition. https://www.w3.org/TR/xmlschema11-2/#NCName.
A textual label that provides a sub-type or characterization of the property’s name.
An identifier for relating distinct sets of properties.
A textual label, within a namespace, that uniquely identifies a specific attribute, characteristic, or quality of the property’s containing object.
Selecting a control by its ID given as a literal.
A textual label that provides a sub-type or characterization of the group.
Identifies the group.
A textual label that provides a characterization of the type, purpose, use or scope of the parameter.
(deprecated) Another parameter invoking this one. This construct has been deprecated and should not be used.
A unique identifier for the parameter.
An optional textual providing a sub-type or characterization of the part’s name, or a category to which the part belongs.
A unique identifier for the part.
A textual label that uniquely identifies the part’s semantic type, which exists in a value space qualified by the ns.
A reference to a role performed by a party.
The type of action documented by the assembly, such as an approval.
A unique identifier for the role.
Target location of the addition.
A reference to a control with a corresponding id value. When referencing an externally defined control, the Control Identifier Reference must be used in the context of the external / imported OSCAL instance (e.g., uri-reference).
Identify items to remove by matching their class.
Identify items to remove indicated by their id.
Identify items remove by matching their assigned name.
Identify items to remove by the item’s ns, which is the namespace associated with a part, or prop.
A textual label that provides a characterization of the parameter.
(deprecated) Another parameter invoking this one. This construct has been deprecated and should not be used.
An identifier for the parameter.
Describes the type of relationship provided by the link’s hypertext reference. This can be an indicator of the link’s purpose.
Indicates the type of address.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive