pub struct ServiceProtocolInformationBuilder { /* private fields */ }Expand description
Builder for ServiceProtocolInformation.
Implementations
Sourceimpl ServiceProtocolInformationBuilder
impl ServiceProtocolInformationBuilder
Sourcepub fn name<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn name<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
The common name of the protocol, which should be the appropriate “service name” from the IANA Service Name and Transport Protocol Port Number Registry.
pub fn port_ranges<VALUE: Into<Vec<PortRange>>>( &mut self, value: VALUE, ) -> &mut Self
Sourcepub fn title<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn title<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
A human readable name for the protocol (e.g., Transport Layer Security).
Sourcepub fn uuid<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
pub fn uuid<VALUE: Into<String>>(&mut self, value: VALUE) -> &mut Self
A machine-oriented, globally unique identifier with cross-instance scope that can be used to reference this service protocol information elsewhere in this or other OSCAL instances. The locally defined UUID of the service protocol can be used to reference the data item locally or globally (e.g., in an imported OSCAL instance). This UUID should be assigned per-subject, which means it should be consistently used to identify the same subject across revisions of the document.
Sourcepub fn build(
&self,
) -> Result<ServiceProtocolInformation, ServiceProtocolInformationBuilderError>
pub fn build( &self, ) -> Result<ServiceProtocolInformation, ServiceProtocolInformationBuilderError>